@@ -1,4 +1,4 @@
-;;; ob-eukleides.el --- Org-babel functions for eukleides evaluation
+;;; ob-eukleides.el --- Org-babel functions for eukleides evaluation  -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2010-2021  Free Software Foundation, Inc.
 
@@ -58,36 +58,33 @@
 (defun org-babel-execute:eukleides (body params)
   "Execute a block of eukleides code with org-babel.
 This function is called by `org-babel-execute-src-block'."
-  (let* ((result-params (split-string (or (cdr (assq :results params)) "")))
-	 (out-file (or (cdr (assq :file params))
+  (let* ((out-file (or (cdr (assq :file params))
 		       (error "Eukleides requires a \":file\" header argument")))
-	 (cmdline (cdr (assq :cmdline params)))
 	 (in-file (org-babel-temp-file "eukleides-"))
-	 (java (or (cdr (assq :java params)) ""))
 	 (cmd (if (not org-eukleides-path)
 		  (error "`org-eukleides-path' is not set")
 		(concat (expand-file-name org-eukleides-path)
-                " -b --output="
-                (org-babel-process-file-name
-                 (concat
-                  (file-name-sans-extension out-file) ".eps"))
-                " "
-                (org-babel-process-file-name in-file)))))
+			" -b --output="
+			(org-babel-process-file-name
+			 (concat
+			  (file-name-sans-extension out-file) ".eps"))
+			" "
+			(org-babel-process-file-name in-file)))))
     (unless (file-exists-p org-eukleides-path)
       (error "Could not find eukleides at %s" org-eukleides-path))
 
     (if (string= (file-name-extension out-file) "png")
         (if org-eukleides-eps-to-raster
             (shell-command (format org-eukleides-eps-to-raster
-                                    (concat (file-name-sans-extension out-file) ".eps")
-                                    (concat (file-name-sans-extension out-file) ".png")))
+                                   (concat (file-name-sans-extension out-file) ".eps")
+                                   (concat (file-name-sans-extension out-file) ".png")))
           (error "Conversion to PNG not supported.  Use a file with an EPS name")))
 
     (with-temp-file in-file (insert body))
     (message "%s" cmd) (org-babel-eval cmd "")
     nil)) ;; signal that output has already been written to file
 
-(defun org-babel-prep-session:eukleides (session params)
+(defun org-babel-prep-session:eukleides (_session _params)
   "Return an error because eukleides does not support sessions."
   (error "Eukleides does not support sessions"))
 
