@@ -1,4 +1,4 @@
-;;; ob-mathomatic.el --- Org-babel functions for mathomatic evaluation
+;;; ob-mathomatic.el --- Org-babel functions for mathomatic evaluation  -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2009-2021  Free Software Foundation, Inc.
 
@@ -45,7 +45,8 @@
 (defcustom org-babel-mathomatic-command
   (if (boundp 'mathomatic-command) mathomatic-command "mathomatic")
   "Command used to call mathomatic on the shell."
-  :group 'org-babel)
+  :group 'org-babel
+  :type 'string)
 
 (defun org-babel-mathomatic-expand (body params)
   "Expand a block of Mathomatic code according to its header arguments."
@@ -93,17 +94,16 @@ called by `org-babel-execute-src-block'."
 			     org-babel-mathomatic-command in-file cmdline)))
 	   (with-temp-file in-file (insert (org-babel-mathomatic-expand body params)))
 	   (message cmd)
-	   ((lambda (raw) ;; " | grep -v batch | grep -v 'replaced' | sed '/^$/d' "
-	      (mapconcat
-	       #'identity
-	       (delq nil
-		     (mapcar (lambda (line)
-			       (unless (or (string-match "batch" line)
-					   (string-match "^rat: replaced .*$" line)
-					   (= 0 (length line)))
-				 line))
-			     (split-string raw "[\r\n]"))) "\n"))
-	    (org-babel-eval cmd "")))))
+	   ;; " | grep -v batch | grep -v 'replaced' | sed '/^$/d' "
+	   (mapconcat
+	    #'identity
+	    (delq nil
+		  (mapcar (lambda (line)
+			    (unless (or (string-match "batch" line)
+					(string-match "^rat: replaced .*$" line)
+					(= 0 (length line)))
+			      line))
+			  (split-string (org-babel-eval cmd "") "[\r\n]"))) "\n"))))
     (if (org-babel-mathomatic-graphical-output-file params)
 	nil
       (if (or (member "scalar" result-params)
@@ -114,7 +114,7 @@ called by `org-babel-execute-src-block'."
 	  (with-temp-file tmp-file (insert result))
 	  (org-babel-import-elisp-from-file tmp-file))))))
 
-(defun org-babel-prep-session:mathomatic (session params)
+(defun org-babel-prep-session:mathomatic (_session _params)
   (error "Mathomatic does not support sessions"))
 
 (defun org-babel-mathomatic-var-to-mathomatic (pair)
