@@ -1,4 +1,4 @@
-;;; ob-vbnet.el --- org-babel functions for VB.Net evaluation
+;;; ob-vbnet.el --- org-babel functions for VB.Net evaluation  -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2011-2021 Free Software Foundation, Inc.
 
@@ -55,12 +55,11 @@ parameters may be used, like vbnc /warnaserror+"
 	 (cmpflag (or (cdr (assq :cmpflag params)) ""))
 	 (cmdline (or (cdr (assq :cmdline params)) ""))
 	 (src-file (org-babel-temp-file "vbnet-src-" ".vb"))
-	 (exe-file (concat (file-name-sans-extension src-file)  ".exe"))
-	 (compile
-	  (progn (with-temp-file  src-file (insert full-body))
-		 (org-babel-eval
-		  (concat org-babel-vbnet-compiler " " cmpflag " " src-file)
-		  ""))))
+	 (exe-file (concat (file-name-sans-extension src-file)  ".exe")))
+    ;; Compile.
+    (with-temp-file  src-file (insert full-body))
+    (org-babel-eval
+     (concat org-babel-vbnet-compiler " " cmpflag " " src-file) "")
     (let ((results (org-babel-eval (concat org-babel-vbnet-command " " cmdline " " exe-file) "")))
       (org-babel-reassemble-table
        (org-babel-result-cond (cdr (assq :result-params params))
@@ -73,7 +72,7 @@ parameters may be used, like vbnc /warnaserror+"
        (org-babel-pick-name
         (cdr (assq :rowname-names params)) (cdr (assq :rownames params)))))))
 
-(defun org-babel-prep-session:vbnet (session params)
+(defun org-babel-prep-session:vbnet (_session _params)
   "Return an error because vbnet does not support sessions."
   (error "Sessions are not supported for VB.Net"))
 
