@@ -37,10 +37,7 @@
 (require 'org)
 (require 'ob-core)
 (require 'eldoc)
-
-(declare-function org-element-at-point "org-element" ())
-(declare-function org-element-property "org-element" (property element))
-(declare-function org-element-type "org-element" (element))
+(require 'org-element)
 
 (defgroup org-eldoc nil "" :group 'org)
 
@@ -69,7 +66,8 @@
            (frame-width) "" org-eldoc-breadcrumb-separator))))))
 
 (defun org-eldoc-get-src-header ()
-  "Returns lang and list of header properties if on src definition line and nil otherwise."
+  "On src line, return lang and list of header properties.
+Return nil when not on src line."
   (let ((case-fold-search t) info lang hdr-args)
     (save-excursion
       (beginning-of-line)
@@ -83,14 +81,14 @@
            ": "
            (mapconcat
             (lambda (elem)
-              (when-let* ((val (and (cdr elem)
-                                    (format "%s" (cdr elem))))
-                          (_ (not (string-empty-p val))))
-                (concat
-                 (propertize (symbol-name (car elem)) 'face 'org-list-dt)
-                 " "
-                 (propertize val 'face 'org-verbatim)
-                 " ")))
+              (when-let ((val (and (cdr elem)
+                                   (format "%s" (cdr elem)))))
+                (unless (string-empty-p val)
+                  (concat
+                   (propertize (symbol-name (car elem)) 'face 'org-list-dt)
+                   " "
+                   (propertize val 'face 'org-verbatim)
+                   " "))))
             hdr-args " ")))))))
 
 (defun org-eldoc-get-src-lang ()
@@ -203,7 +201,6 @@
       (add-function :before-until (local 'eldoc-documentation-function)
 		    #'org-eldoc-documentation-function)))))
 
-;;;###autoload
 (add-hook 'org-mode-hook #'org-eldoc-load)
 
 (provide 'org-eldoc)
